[![Stories in Ready](http://badge.waffle.io/rochacbruno/quokka.png)](http://waffle.io/rochacbruno/quokka)  [![Build Status](https://drone.io/github.com/rochacbruno/quokka/status.png)](https://drone.io/github.com/rochacbruno/quokka/latest) [![Twitter](https://twitter.com/images/resources/twitter-bird-16x16.png)](http://twitter.com/quokkaproject) [@quokkaproject](http://twitter.com/quokkaproject "@quokkaproject on twitter")  

quokka project
======

![logo](/docs/logo.png)

